==> zio-aws-route53resolver_3-5.17.121.2-sources.jar: zio/aws/route53resolver/model/GetResolverRuleAssociationResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetResolverRuleAssociationResponse(
    resolverRuleAssociation: Option[
      zio.aws.route53resolver.model.ResolverRuleAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse = {
    import GetResolverRuleAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse
      .builder()
      .optionallyWith(
        resolverRuleAssociation.map(value => value.buildAwsValue())
      )(_.resolverRuleAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.GetResolverRuleAssociationResponse.ReadOnly =
    zio.aws.route53resolver.model.GetResolverRuleAssociationResponse
      .wrap(buildAwsValue())
}
object GetResolverRuleAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.GetResolverRuleAssociationResponse =
      zio.aws.route53resolver.model.GetResolverRuleAssociationResponse(
        resolverRuleAssociation.map(value => value.asEditable)
      )
    def resolverRuleAssociation
        : Option[zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly]
    def getResolverRuleAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resolverRuleAssociation",
      resolverRuleAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse
  ) extends zio.aws.route53resolver.model.GetResolverRuleAssociationResponse.ReadOnly {
    override val resolverRuleAssociation: Option[
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = scala
      .Option(impl.resolverRuleAssociation())
      .map(value =>
        zio.aws.route53resolver.model.ResolverRuleAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse
  ): zio.aws.route53resolver.model.GetResolverRuleAssociationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53resolver_3-5.17.195.1-sources.jar: zio/aws/route53resolver/model/GetResolverRuleAssociationResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetResolverRuleAssociationResponse(
    resolverRuleAssociation: Optional[
      zio.aws.route53resolver.model.ResolverRuleAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse = {
    import GetResolverRuleAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse
      .builder()
      .optionallyWith(
        resolverRuleAssociation.map(value => value.buildAwsValue())
      )(_.resolverRuleAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.GetResolverRuleAssociationResponse.ReadOnly =
    zio.aws.route53resolver.model.GetResolverRuleAssociationResponse
      .wrap(buildAwsValue())
}
object GetResolverRuleAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.GetResolverRuleAssociationResponse =
      zio.aws.route53resolver.model.GetResolverRuleAssociationResponse(
        resolverRuleAssociation.map(value => value.asEditable)
      )
    def resolverRuleAssociation: Optional[
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ]
    def getResolverRuleAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resolverRuleAssociation",
      resolverRuleAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse
  ) extends zio.aws.route53resolver.model.GetResolverRuleAssociationResponse.ReadOnly {
    override val resolverRuleAssociation: Optional[
      zio.aws.route53resolver.model.ResolverRuleAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.resolverRuleAssociation())
      .map(value =>
        zio.aws.route53resolver.model.ResolverRuleAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.GetResolverRuleAssociationResponse
  ): zio.aws.route53resolver.model.GetResolverRuleAssociationResponse.ReadOnly =
    new Wrapper(impl)
}
